.. ubii-node-python documentation master file, created by
   sphinx-quickstart on Tue Feb  1 10:29:12 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Ubi Interact Python Framework
=============================

This site covers the Ubi Interact Python Node's usage & API documentation. For basic info on what
Ubi Interact is see `the main project website <https://github.com/SandroWeber/ubi-interact/wiki>`_.

Getting started
---------------

Many core ideas & API calls are explained in the tutorial/getting-started
document:

.. toctree::
    :maxdepth: 2

    getting-started


.. _concepts-docs:

Concepts
--------

Dig deeper into specific topics:

.. toctree::
    :maxdepth: 2
    :glob:

    concepts/*


.. _api-docs:

API
---

Know what you're looking for & just need API details? auto-generated API documentation is here:

.. toctree::
   :maxdepth: 1
   :glob:

   api/ubii/ubii
   api/codestare/codestare

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
